==> ferium-3.21.0.crate: ferium-3.21.0/src/subcommands/remove.rs <==
use anyhow::{bail, Result};
use dialoguer::{theme::ColorfulTheme, MultiSelect};
use libium::config;

/// Display a list of mods and repos in the profile to select from and remove selected ones
pub fn remove(
    profile: &mut config::structs::Profile,
    mod_names: Option<Vec<String>>,
) -> Result<()> {
    let names = profile
        .mods
        .iter()
        .map(|mod_| &mod_.name)
        .collect::<Vec<_>>();
    let mut items_to_remove = Vec::new();

    match mod_names {
        Some(mod_names) => {
            for mod_name in mod_names {
                if let Some(index) = names
                    .iter()
                    .position(|name| name.to_lowercase() == mod_name.to_lowercase())
                {
                    items_to_remove.push(index);
                } else {
                    bail!("A mod called {} is not present in this profile", mod_name);
                }
            }
        },
        None => {
            items_to_remove = match MultiSelect::with_theme(&ColorfulTheme::default())
                .with_prompt("Select mods to remove")
                .items(&names)
                .interact_opt()?
            {
                Some(items_to_remove) => items_to_remove,
                None => return Ok(()), // Exit if the user cancelled
            };
        },
    }

    // Sort the indices in ascending order to fix moving indices during removal
    items_to_remove.sort_unstable();
    items_to_remove.reverse();
    for index in items_to_remove {
        profile.mods.swap_remove(index);
    }

    Ok(())
}

==> ferium-3.25.1.crate: ferium-3.25.1/src/subcommands/remove.rs <==
use anyhow::{bail, Result};
use dialoguer::MultiSelect;
use libium::config;

/// Display a list of mods and repos in the profile to select from and remove selected ones
pub fn remove(
    profile: &mut config::structs::Profile,
    mod_names: Option<Vec<String>>,
) -> Result<()> {
    let names = profile
        .mods
        .iter()
        .map(|mod_| &mod_.name)
        .collect::<Vec<_>>();
    let mut items_to_remove = Vec::new();

    match mod_names {
        Some(mod_names) => {
            for mod_name in mod_names {
                if let Some(index) = names
                    .iter()
                    .position(|name| name.to_lowercase() == mod_name.to_lowercase())
                {
                    items_to_remove.push(index);
                } else {
                    bail!("A mod called {} is not present in this profile", mod_name);
                }
            }
        },
        None => {
            items_to_remove = match MultiSelect::with_theme(&*crate::THEME)
                .with_prompt("Select mods to remove")
                .items(&names)
                .interact_opt()?
            {
                Some(items_to_remove) => items_to_remove,
                None => return Ok(()), // Exit if the user cancelled
            };
        },
    }

    // Sort the indices in ascending order to fix moving indices during removal
    items_to_remove.sort_unstable();
    items_to_remove.reverse();
    for index in items_to_remove {
        profile.mods.swap_remove(index);
    }

    Ok(())
}
